@@ -25,7 +25,7 @@ impl OptsCommon {
         self.db_file = shellexpand::full(&self.db_file)?.into_owned();
         Ok(())
     }
-    fn get_loglevel(&self) -> LevelFilter {
+    pub fn get_loglevel(&self) -> LevelFilter {
         if self.trace {
             LevelFilter::Trace
         } else if self.debug {
